"""
Helper Models - Erweiterte Modelle mit High-Level Funktionen

Diese Modelle erweitern die API-generierten Basismodelle mit zusaetzlichen
Funktionen und erleichtern die Verwendung der sevDesk API.
"""

from sevdesk.helpermodels.invoice_ext import InvoiceExt

__all__ = ['InvoiceExt']
